from .vector_data_store import VectorDataStore
from .vector import _Vector

import os

class Tychos:
    @property
    def api_key(self):
        return os.getenv('TYCHOS_API_KEY')

    @api_key.setter
    def api_key(self, value):
        os.environ['TYCHOS_API_KEY'] = value


import os
import requests
from .vector import _Vector

class VectorDataStore:
    def __init__(self, api_key=None):
        self.api_key = api_key or os.getenv('TYCHOS_API_KEY')
        self.base_url = 'https://api.tychos.ai/api/'
        # self.base_url = 'http://localhost:3001/api/'
        self.vector = _Vector(api_key=self.api_key)

    def query(self, name, query_string, limit):
        if self.api_key is None:
            raise ValueError("API key not set. Please set the API key using 'tychos.api_key = <your_api_key>'. If you need to create an API key, you can go so at tychos.ai")
        # vectorize query string
        query_vector = self.vector.create(
            type="text_embedding",
            input_text=query_string,
            model="text-embedding-ada-002"
        )

        # send query request to vector data store
        url = f'{self.base_url}query-vector-store'
        headers = {'api_key': self.api_key}
        payload = {
                    'name': name,
                    'query_vector': query_vector,
                    'top': limit,
                }
        response = requests.post(url=url, headers=headers, json=payload)

        # error handling
        response.raise_for_status()

        return response.json()
    
    def list(self):
        if self.api_key is None:
            raise ValueError("API key not set. Please set the API key using 'tychos.api_key = <your_api_key>'. If you need to create an API key, you can go so at tychos.ai")
        url = f'{self.base_url}datasets'
        headers = {'api_key': self.api_key}
        response = requests.get(url=url, headers=headers)

        # error handling
        response.raise_for_status()

        return response.json()


import sys
import argparse
from .vector_data_store import VectorDataStore

def query(args):
    tds = VectorDataStore(api_key=args.api_key)
    result = tds.query(args.name, args.query_string, args.limit)
    print(result)

def main():
    parser = argparse.ArgumentParser(description='Tychos CLI')
    subparsers = parser.add_subparsers()

    query_parser = subparsers.add_parser('query')
    query_parser.add_argument('--api-key', required=True, help='Tychos API key')
    query_parser.add_argument('--name', required=True, help='name of the index to query')
    query_parser.add_argument('--query-string', required=True, help='query string to search against index')
    query_parser.add_argument('--limit', type=int, default=5, help='number of results to return')
    query_parser.set_defaults(func=query)

    args = parser.parse_args()
    if 'func' in args:
        # Call the function associated with the provided sub-command
        args.func(args)
    else:
        # No sub-command was provided
        parser.print_help()
        sys.exit(1)

if __name__ == "__main__":
    main()


import os
import requests

class _Vector:
    def __init__(self, api_key=None):
        self.api_key = api_key or os.getenv('TYCHOS_API_KEY')
        self.base_url = 'https://api.tychos.ai/api/'
        # self.base_url = 'http://localhost:3001/api/'
        
    def create(self, type, input_text, model, model_provider_key=None):
        if self.api_key is None:
            raise ValueError("API key not set. Please set the API key using 'tychos.api_key = <your_api_key>'. If you need to create an API key, you can go so at tychos.ai")
        if type == "text_embedding":
            if model == "text-embedding-ada-002":
                try:
                    url = f'{self.base_url}create-vector'
                    headers = {'api_key': self.api_key}
                    payload = {
                                'model_provider_key': model_provider_key,
                                'input': input_text,
                                'model': model,
                            }
                    response = requests.post(url=url, headers=headers, json=payload)

                    # error handling
                    response.raise_for_status()

                    return response.json()
                except Exception as e:
                    print(e)
                    return None
            else:
                print("Model not currently supported, try text-embedding-ada-002")
                return None
        else:
            print("Type not currently supported, try text_embedding")
            return None
    


from setuptools import setup

with open('README.md', 'r', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

setup(
    version='0.0.8',
    description='Python client library for the Tychos API.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.6',
    install_requires=[
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'tychos-cli=tychos.cli:main',
        ],
    },
)


class TychosConfig:
    def __init__(self):
        self._api_key = None

    def __get__(self, instance, owner):
        return self._api_key

    def __set__(self, instance, value):
        self._api_key = value